@@ -690,7 +690,7 @@ gsBoundSummary <- function(x, deltaname = NULL, logdelta = FALSE, Nname = NULL,
     nstat <- 2
   } else {
     nstat <- 4
-    statframe[statframe$Value == statframe$Value[3], ]$Analysis <- paste("Events:", ceiling(rowSums(x$eDC + x$eDE)))
+    statframe[statframe$Value == statframe$Value[3], ]$Analysis <- paste("Events:", ceiling(x$n.I))
     if (x$ratio == 1) N <- 2 * ceiling(rowSums(x$eNE)) else N <- ceiling(rowSums(x$eNE)) + ceiling(rowSums(x$eNC))
     Time <- round(x$T, tdigits)
     statframe[statframe$Value == statframe$Value[4], ]$Analysis <- paste(timename, ": ", as.character(Time), sep = "")
@@ -777,6 +777,7 @@ sfprint <- function(x) {
 
 # summary.spendfn roxy [sinew] ----
 #' @export
+#' @rdname spendingFunction
 #' @aliases summary.spendfn
 # summary.spendfn function [sinew] ----
 summary.spendfn <- function(object, ...) {
