@@ -48,21 +48,22 @@ testthat::test_that(desc = "Test: zi is not a scalar",
   expect_error(gsCP(x, theta = NULL, i = 2, zi = c(1, 2), r = 18))
 })
 
-
-testthat::test_that(desc = "Test: out of range zi - test.type = 2 ", 
-                    code = {
-  x <- gsDesign(k = 3, test.type = 2, n.fix = 800)
-  local_edition(3)
-  expect_error(gsCP(x, theta = NULL, i = 2, zi = 3, r = 18))
-})
+# 2022June28: KA Removed range check, test no longer relevant
+# testthat::test_that(desc = "Test: out of range zi - test.type = 2 ", 
+#                     code = {
+#   x <- gsDesign(k = 3, test.type = 2, n.fix = 800)
+#   local_edition(3)
+#   expect_error(gsCP(x, theta = NULL, i = 2, zi = 3, r = 18))
+# })
 
 
-testthat::test_that(desc = "Test: out of range zi - test.type = 3", 
-                    code = {
-  x <- gsDesign(k = 3, test.type = 3, n.fix = 800)
-  local_edition(3)
-  expect_error(gsCP(x, theta = 0.5, i = 1, zi = -0.5, r = 80))
-})
+# 2022June28: KA Removed range check, test no longer relevant
+# testthat::test_that(desc = "Test: out of range zi - test.type = 3", 
+#                     code = {
+#   x <- gsDesign(k = 3, test.type = 3, n.fix = 800)
+#   local_edition(3)
+#   expect_error(gsCP(x, theta = 0.5, i = 1, zi = -0.5, r = 80))
+# })
 
 
 testthat::test_that(desc = "Test: output with theta null,
